/*
 * Вспомогательные функции
 */

// Режим по умолчанию (при старте)
// Возможные значение - income, amount, payment, term
var mode = "income";
var currency = "rub";

/*
 * Проверка поля на пустоту
 */
function checkEmpty(id)
{
	var node = document.getElementById(id);
	if (!node) return false;
	if (node.value == "") return false;
	return true;
}

/*
 * Проверка соответствия поля типу float
 * Если число неположительное или больше 10^9 возвращается ошибка
 */
function checkFloat(id)
{
	var node = document.getElementById(id);
	if (!node) return false;
	if (node.value == "") return false;
	if (isNaN(node.value)) return false;
	if (node.value <= 0)
		return false;
	if (node.value > 1000000000)
		return false;
	return true;
}

/*
 * Переместить фокус на данное поле, возможно, с изменением стиля на "ошибочный"
 */
function focus(id, err)
{
	var node = document.getElementById(id);
	if (!node) return false;
	node.focus();
	if (err)
		node.className = "ic-error";
		//node.setAttribute("class", "ic-error")
	else if (id == "submit")
		node.className = "";
		//node.setAttribute("class", "")
	return true;
}

/*
 * Обработка ошибки для какого-то из полей ввода
 * Устанавливает на него фокус и выдает в нижним поле сообщение об ошибке
 * Если text  пусто, то сообщение об ошибке убирается
 */
function error(id, text)
{
	var node = document.getElementById("error-div");
	if (node) {
		while (node.hasChildNodes())
			node.removeChild(node.firstChild);
		if (text != "") {
			node.className = "ic-visible";
			div = document.createElement("div");
			//div.setAttribute("class", "error-div");
			div.appendChild(document.createTextNode(text));
			node.appendChild(div);
		} else 
			node.className = "ic-hidden";
	}
	focus(id, text != '');
	return false;
}

/*
 * Отключает данное поле ввода
 */
function update_disable(id) {
	var node = document.getElementById(id);
	if (!node) return;
	//node.value = "";
	node.setAttribute('disabled', 'disabled');
	node.className = 'ic-ro';
}

/*
 * Отключает данное поле ввода и маркирует его как выходной результат
 */
function update_output(id) {
	var node = document.getElementById(id);
	if (!node) return;
	//node.value = "";
	node.setAttribute('disabled', 'disabled');
	node.className = 'ic-out';
	node.value = '0';
}

/*
 * Включает данное поле ввода
 */
function update_enable(id) {
	var node = document.getElementById(id);
	if (!node) return;
	node.removeAttribute('disabled');
	node.className = 'ic-rw';
}

/*
 * Включает/отключает поля для режима "От дохода"
 */
function update_form_income() {
	update_enable('term');
	update_enable('income');
	update_enable('family');
	update_enable('cash');
	update_output('amount');
	update_output('cost');
	update_output('insurance');
	update_output('payment');
}

/*
 * Включает/отключает поля в соответствии с данным режимом
 */
function update()
{
	error('submit', '');
	mode = "income";
	update_form_income();
}

/*
 * Производит вычисления в соответствии с данным режимом
 * Возвращает строку с информацией об ошибке
 */
function calc() { 
	c_rate = 0.01 * document.getElementById("rate").value;
	c_ins_rate = 0.01 * document.getElementById("ins_rate").value;
	if (mode == "amount")
		return calc_mode_amount();
	else if (mode == "term")
		return calc_mode_term();
	else if (mode == "payment")
		return calc_mode_payment();
	else if (mode == "income")
		return calc_mode_income();
	else error("submit", "Неизвестный режим");
}

/*
 * Производит проверку корректности всех полей и производит вычисление
 * Ограничения:
 * income - не меньше прожиточного минимума (4900)
 * family - не меньше 1 и не больше 50
 * term - не меньше 1 года и не больше 30
 */
function validate()
{
	update();
	if (!checkFloat('rate')) return error('rate', 'Некорректное значение процентной ставки');
	if (!checkFloat('ins_rate')) return error('ins_rate', 'Некорректное значение ставки страхования');
	var tmp_val = 0;
	if (!checkFloat('term'))
		return error('term', 'Некорректное значение срока кредита');
	tmp_val = 1. * document.getElementById('term').value;
	if (tmp_val < 1) return error('term', 'Сроа кредита должен быть не меньше одного года');
	if (tmp_val > 30) return error('term', 'Срок кредита должен быть не больше 30 лет');
	if (!checkFloat('income'))
		return error('income', 'Некорректное значение совокупного дохода');
	tmp_val = 1. * document.getElementById('income').value;
	if (tmp_val < c_minimum) return error('income', 'Совокупный доход не может быть меньше прожиточного минимума');
	if (!checkFloat('family'))
		return error('family', 'Некорректное значение числености семьи');
	tmp_val = 1. * document.getElementById('family').value;
	if (tmp_val < 1) return error('family', 'Количество членов семьи не может быть меньше одного');
	if (tmp_val > 50) return error('family', 'Количество членов семьи не может быть больше 50');
	if (!checkFloat('cash')) 
		return error('cash', 'Некорректное значение размера собственных средств');
	var err = calc();
	if (err && err != '') error('submit', err);
	return false;
}

